package main

import androidx.compose.foundation.layout.*
import androidx.compose.material.*
import androidx.compose.runtime.*
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.unit.dp

var mostUsedWordList = mutableMapOf<String, Int>()
@Composable
fun homePage(
    onGlossaryClick: () -> Unit,
    onCodeToVerifyClick: () -> Unit
) {
    val noFileSnackbarVisibleState = remember { mutableStateOf(false) }

    Column(
        modifier = Modifier.fillMaxSize(),
        verticalArrangement = Arrangement.Center,
        horizontalAlignment = Alignment.CenterHorizontally
    ) {
        Text("Quali'Nomme", style = MaterialTheme.typography.h3)

        var isCompareClicked by remember { mutableStateOf(false) }

        Spacer(modifier = Modifier.height(16.dp))

        Column { // Wrap the Row in a Column
            Row(
                horizontalArrangement = Arrangement.spacedBy(16.dp)
            ) {
                Button(
                    onClick = onGlossaryClick,
                    modifier = Modifier
                        .width(200.dp),
                    colors = ButtonDefaults.buttonColors(
                        backgroundColor = customRedColor,
                        contentColor = Color.White
                    )
                ) {
                    Text("Glossaire")
                }

                Button(
                    onClick = onCodeToVerifyClick,
                    modifier = Modifier
                        .width(200.dp),
                    colors = ButtonDefaults.buttonColors(
                        backgroundColor = customRedColor,
                        contentColor = Color.White
                    )
                ) {
                    Text("Code à Vérifier")
                }

                Button(
                    onClick = {
                        //if file not uploaded show snackbar
                        if (mostUsedWordList.isEmpty()) {
                            noFileSnackbarVisibleState.value = true
                            println("Veuillez d'abord importer un fichier")
                            return@Button
                        } else {
                            isCompareClicked = true
                        }

                    },
                    modifier = Modifier
                        .width(200.dp),
                    colors = ButtonDefaults.buttonColors(
                        backgroundColor = customRedColor,
                        contentColor = Color.White
                    ),
                    //disable if file not uploaded
                    enabled = mostUsedWordList.isNotEmpty()
                ) {
                    Text("Comparer")
                }
            }

        }

        if (noFileSnackbarVisibleState.value) {
            Snackbar(
                modifier = Modifier.padding(16.dp),
                action = {
                    Button(
                        onClick = { noFileSnackbarVisibleState.value = false },
                        colors = ButtonDefaults.buttonColors(
                            backgroundColor = customRedColor,
                            contentColor = Color.White
                        )
                    ) {
                        Text("OK")
                    }
                }
            ) {
                Text("Veuillez d'abord importer un fichier")
            }
        }

        if (isCompareClicked) {
            println(mostUsedWordList.keys.toList())
            compareResults(
                glossaryWords = loadDatasFromFile(),
                codeWords = mostUsedWordList.keys.toList(),
                onBackClick = { isCompareClicked = false }
            )
        }
    }
}
